[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Xen-changelog] [xen-3.1-testing] Merge with xen-unstable for 3.1.0-rc9



# HG changeset patch
# User kfraser@xxxxxxxxxxxxxxxxxxxxx
# Date 1178627984 -3600
# Node ID 5b9b0c79ccc342bba2e6dec57895f84f3e8a3991
# Parent  4b09552012011d4a09e0f03c9b570862a0319109
# Parent  d2ef85c6bf84cc619ca2d42c2edfc6229e70a6ad
Merge with xen-unstable for 3.1.0-rc9
---
 linux-2.6-xen-sparse/drivers/xen/core/machine_reboot.c                  |   12 
++++-
 patches/linux-2.6.18/git-5ee7737379b1d7f0c977c0f1661fbaf01a8d4721.patch |   21 
++++++++++
 patches/linux-2.6.18/series                                             |    1 
 tools/ioemu/keymaps/modifiers                                           |    2 
 tools/ioemu/patches/vnc-altgr-keysym                                    |    5 
--
 tools/python/xen/xend/XendDomainInfo.py                                 |    5 
+-
 tools/python/xen/xend/image.py                                          |    2 
 tools/xenstat/libxenstat/src/xenstat_linux.c                            |    6 
--
 xen/Makefile                                                            |    2 
 xen/arch/x86/mm/shadow/common.c                                         |   11 
+++--
 10 files changed, 50 insertions(+), 17 deletions(-)

diff -r 4b0955201201 -r 5b9b0c79ccc3 
linux-2.6-xen-sparse/drivers/xen/core/machine_reboot.c
--- a/linux-2.6-xen-sparse/drivers/xen/core/machine_reboot.c    Sun May 06 
00:27:22 2007 +0100
+++ b/linux-2.6-xen-sparse/drivers/xen/core/machine_reboot.c    Tue May 08 
13:39:44 2007 +0100
@@ -113,10 +113,18 @@ static void post_suspend(int suspend_can
 
 #else /* !(defined(__i386__) || defined(__x86_64__)) */
 
+#ifndef HAVE_XEN_PRE_SUSPEND
+#define xen_pre_suspend()      ((void)0)
+#endif
+
+#ifndef HAVE_XEN_POST_SUSPEND
+#define xen_post_suspend(x)    ((void)0)
+#endif
+
 #define switch_idle_mm()       ((void)0)
 #define mm_pin_all()           ((void)0)
-#define pre_suspend()          ((void)0)
-#define post_suspend(x)                ((void)0)
+#define pre_suspend()          xen_pre_suspend()
+#define post_suspend(x)                xen_post_suspend(x)
 
 #endif
 
diff -r 4b0955201201 -r 5b9b0c79ccc3 
patches/linux-2.6.18/git-5ee7737379b1d7f0c977c0f1661fbaf01a8d4721.patch
--- /dev/null   Thu Jan 01 00:00:00 1970 +0000
+++ b/patches/linux-2.6.18/git-5ee7737379b1d7f0c977c0f1661fbaf01a8d4721.patch   
Tue May 08 13:39:44 2007 +0100
@@ -0,0 +1,28 @@
+--- ./arch/ia64/kernel/smp.c.orig      2007-05-02 19:00:01.000000000 +0900
++++ ./arch/ia64/kernel/smp.c   2007-05-02 19:04:32.000000000 +0900
+@@ -328,10 +328,14 @@ int
+ smp_call_function (void (*func) (void *info), void *info, int nonatomic, int 
wait)
+ {
+       struct call_data_struct data;
+-      int cpus = num_online_cpus()-1;
++      int cpus;
+ 
+-      if (!cpus)
++      spin_lock(&call_lock);
++      cpus = num_online_cpus()-1;
++      if (!cpus) {
++              spin_unlock(&call_lock);
+               return 0;
++      }
+ 
+       /* Can deadlock when called with interrupts disabled */
+       WARN_ON(irqs_disabled());
+@@ -343,8 +347,6 @@ smp_call_function (void (*func) (void *i
+       if (wait)
+               atomic_set(&data.finished, 0);
+ 
+-      spin_lock(&call_lock);
+-
+       call_data = &data;
+       mb();   /* ensure store to call_data precedes setting of IPI_CALL_FUNC 
*/
+       send_IPI_allbutself(IPI_CALL_FUNC);
diff -r 4b0955201201 -r 5b9b0c79ccc3 patches/linux-2.6.18/series
--- a/patches/linux-2.6.18/series       Sun May 06 00:27:22 2007 +0100
+++ b/patches/linux-2.6.18/series       Tue May 08 13:39:44 2007 +0100
@@ -21,3 +21,4 @@ softlockup-no-idle-hz.patch
 softlockup-no-idle-hz.patch
 allow-i386-crash-kernels-to-handle-x86_64-dumps.patch
 allow-i386-crash-kernels-to-handle-x86_64-dumps-fix.patch
+git-5ee7737379b1d7f0c977c0f1661fbaf01a8d4721.patch
diff -r 4b0955201201 -r 5b9b0c79ccc3 tools/ioemu/keymaps/modifiers
--- a/tools/ioemu/keymaps/modifiers     Sun May 06 00:27:22 2007 +0100
+++ b/tools/ioemu/keymaps/modifiers     Tue May 08 13:39:44 2007 +0100
@@ -3,7 +3,7 @@ Shift_L 0x2a
 
 Alt_R 0xb8
 Mode_switch 0xb8
-ISO_Level3_Switch 0xb8
+ISO_Level3_Shift 0xb8
 Alt_L 0x38
 
 Control_R 0x9d
diff -r 4b0955201201 -r 5b9b0c79ccc3 tools/ioemu/patches/vnc-altgr-keysym
--- a/tools/ioemu/patches/vnc-altgr-keysym      Sun May 06 00:27:22 2007 +0100
+++ b/tools/ioemu/patches/vnc-altgr-keysym      Tue May 08 13:39:44 2007 +0100
@@ -1,19 +1,19 @@ Index: ioemu/keymaps/modifiers
 Index: ioemu/keymaps/modifiers
 ===================================================================
---- ioemu.orig/keymaps/modifiers       2007-05-02 10:30:05.000000000 +0100
-+++ ioemu/keymaps/modifiers    2007-05-03 15:02:56.000000000 +0100
+--- ioemu.orig/keymaps/modifiers       2007-05-08 10:35:13.000000000 +0100
++++ ioemu/keymaps/modifiers    2007-05-08 10:35:57.000000000 +0100
 @@ -3,6 +3,7 @@
  
  Alt_R 0xb8
  Mode_switch 0xb8
-+ISO_Level3_Switch 0xb8
++ISO_Level3_Shift 0xb8
  Alt_L 0x38
  
  Control_R 0x9d
 Index: ioemu/vnc_keysym.h
 ===================================================================
---- ioemu.orig/vnc_keysym.h    2007-05-03 15:02:10.000000000 +0100
-+++ ioemu/vnc_keysym.h 2007-05-03 15:03:03.000000000 +0100
+--- ioemu.orig/vnc_keysym.h    2007-05-08 10:35:14.000000000 +0100
++++ ioemu/vnc_keysym.h 2007-05-08 10:35:14.000000000 +0100
 @@ -215,6 +215,7 @@
  {"Shift_R", 0xffe2},   /* XK_Shift_R */
  {"Super_L", 0xffeb},   /* XK_Super_L */
diff -r 4b0955201201 -r 5b9b0c79ccc3 tools/python/xen/xend/XendDomainInfo.py
--- a/tools/python/xen/xend/XendDomainInfo.py   Sun May 06 00:27:22 2007 +0100
+++ b/tools/python/xen/xend/XendDomainInfo.py   Tue May 08 13:39:44 2007 +0100
@@ -867,7 +867,10 @@ class XendDomainInfo:
 
         # convert two lists into a python dictionary
         vm_details = dict(zip(cfg_vm, vm_details))
-        
+
+        if vm_details['rtc/timeoffset'] == None:
+            vm_details['rtc/timeoffset'] = "0"
+
         for arg, val in vm_details.items():
             if arg in XendConfig.LEGACY_CFG_TO_XENAPI_CFG:
                 xapiarg = XendConfig.LEGACY_CFG_TO_XENAPI_CFG[arg]
diff -r 4b0955201201 -r 5b9b0c79ccc3 tools/python/xen/xend/image.py
--- a/tools/python/xen/xend/image.py    Sun May 06 00:27:22 2007 +0100
+++ b/tools/python/xen/xend/image.py    Tue May 08 13:39:44 2007 +0100
@@ -418,7 +418,7 @@ class HVMImageHandler(ImageHandler):
             ret.append('-nographic')
 
         if int(vmConfig['platform'].get('monitor', 0)) != 0:
-            ret.append('-monitor vc')
+            ret = ret + ['-monitor', 'vc']
         return ret
 
     def createDeviceModel(self, restore = False):
diff -r 4b0955201201 -r 5b9b0c79ccc3 
tools/xenstat/libxenstat/src/xenstat_linux.c
--- a/tools/xenstat/libxenstat/src/xenstat_linux.c      Sun May 06 00:27:22 
2007 +0100
+++ b/tools/xenstat/libxenstat/src/xenstat_linux.c      Tue May 08 13:39:44 
2007 +0100
@@ -206,10 +206,8 @@ int xenstat_collect_vbds(xenstat_node * 
 
 
                ret = sscanf(dp->d_name, "vbd-%u-%u", &domid, &vbd.dev);
-               if (ret != 2) {
-                       continue;
-               }
-               printf("%s is VBD.\n",dp->d_name);
+               if (ret != 2)
+                       continue;
 
                domain = xenstat_node_domain(node, domid);
                if (domain == NULL) {
diff -r 4b0955201201 -r 5b9b0c79ccc3 xen/Makefile
--- a/xen/Makefile      Sun May 06 00:27:22 2007 +0100
+++ b/xen/Makefile      Tue May 08 13:39:44 2007 +0100
@@ -2,7 +2,7 @@
 # All other places this is stored (eg. compile.h) should be autogenerated.
 export XEN_VERSION       = 3
 export XEN_SUBVERSION    = 1
-export XEN_EXTRAVERSION ?= .0-rc8$(XEN_VENDORVERSION)
+export XEN_EXTRAVERSION ?= .0-rc9$(XEN_VENDORVERSION)
 export XEN_FULLVERSION   = $(XEN_VERSION).$(XEN_SUBVERSION)$(XEN_EXTRAVERSION)
 -include xen-version
 
diff -r 4b0955201201 -r 5b9b0c79ccc3 xen/arch/x86/mm/shadow/common.c
--- a/xen/arch/x86/mm/shadow/common.c   Sun May 06 00:27:22 2007 +0100
+++ b/xen/arch/x86/mm/shadow/common.c   Tue May 08 13:39:44 2007 +0100
@@ -1764,12 +1764,15 @@ int sh_remove_write_access(struct vcpu *
 #if CONFIG_PAGING_LEVELS >= 4
         else if ( v->arch.paging.mode->guest_levels == 4 )
         {
             /* 64bit w2k3: linear map at 0x0000070000000000 */
             switch ( level ) 
             {
-            case 1: GUESS(0x70000000000UL + (fault_addr >> 9), 3); break;
-            case 2: GUESS(0x70380000000UL + (fault_addr >> 18), 3); break;
-            case 3: GUESS(0x70381C00000UL + (fault_addr >> 27), 3); break;
+            case 1: GUESS(0xfffff68000000000UL 
+                          + ((fault_addr & VADDR_MASK) >> 9), 3); break;
+            case 2: GUESS(0xfffff6fb40000000UL
+                          + ((fault_addr & VADDR_MASK) >> 18), 3); break;
+            case 3: GUESS(0xfffff6fb7da00000UL 
+                          + ((fault_addr & VADDR_MASK) >> 27), 3); break;
             }
 
             /* 64bit Linux direct map at 0xffff810000000000; older kernels 
@@ -1764,12 +1764,15 @@ int sh_remove_write_access(struct vcpu *
         else if ( v->arch.paging.mode->guest_levels == 4 )
         {
-            /* 64bit w2k3: linear map at 0x0000070000000000 */
+            /* 64bit w2k3: linear map at 0xfffff68000000000 */
             switch ( level ) 
             {

_______________________________________________
Xen-changelog mailing list
Xen-changelog@xxxxxxxxxxxxxxxxxxx
http://lists.xensource.com/xen-changelog


 


Rackspace

Lists.xenproject.org is hosted with RackSpace, monitoring our
servers 24x7x365 and backed by RackSpace's Fanatical Support®.